==> open-xchange-documents-backend_7.10.0.orig.tar.bz2: open-xchange-documents-backend-7.10.0/com.openexchange.office.filter.core/src/com/openexchange/office/filter/core/Tools.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.core;

import java.awt.image.BufferedImage;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Iterator;
import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.metadata.IIOMetadata;
import javax.imageio.stream.ImageInputStream;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.tuple.Pair;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import com.openexchange.imagetransformation.ImageInformation;
import com.openexchange.java.BoolReference;
import com.openexchange.tools.images.ImageTransformationUtility;

public class Tools {

    public static double[] rotatePoint(double ptX, double ptY, double refX, double refY, double rotation) {
        ptX -= refX;
        ptY -= refY;
        double x = ptX;
        double y = ptY;
        double a = (Math.PI * rotation) / 180.0;
        double s = Math.sin(a);
        double c = Math.cos(a);
        ptX = x * c - y * s;
        ptY = x * s + y * c;
        ptX += refX;
        ptY += refY;
        double[] pts = new double[2];
        pts[0] = ptX;
        pts[1] = ptY;
        return pts;
    }

    public static Pair<Integer, Integer> getPixelSizeFromImage(InputStream inputStream) {

        Pair<Integer, Integer> pixelSize = null;
        BufferedInputStream bufferedInputStream = null;

        try {
            if(inputStream!=null) {
                bufferedInputStream = new BufferedInputStream(inputStream);
                final ImageInformation imageInformation = ImageTransformationUtility.readImageInformation(bufferedInputStream, new BoolReference(false));
                if(imageInformation!=null) {
                    pixelSize = Pair.of(Integer.valueOf(imageInformation.width), Integer.valueOf(imageInformation.height));
                }
                else {
                    bufferedInputStream.reset();
                    final BufferedImage image = ImageIO.read(bufferedInputStream);
                    if(image!=null) {
                        pixelSize = Pair.of(Integer.valueOf(image.getWidth()), Integer.valueOf(image.getHeight()));
                    }
                }
            }
        }
        catch(IOException e) {
            //
        }
        IOUtils.closeQuietly(bufferedInputStream);
        IOUtils.closeQuietly(inputStream);
        return pixelSize;
    }

    /*
     * If available this method returns the original size of the given graphic in 1/100thmm
     */

    public static Pair<Double, Double> getOriginalSizeFromImage(InputStream is) {

        Double originalWidth = null;
        Double originalHeight = null;

        try {

            final ImageInputStream imageInput = ImageIO.createImageInputStream(is);
            if(imageInput!=null) {
                final Iterator<ImageReader> it = ImageIO.getImageReaders(imageInput);
                if (it.hasNext()) {

                    Integer xDPI = null;
                    Integer yDPI = null;

                    final ImageReader reader = it.next();
                    reader.setInput(imageInput);
                    final IIOMetadata meta = reader.getImageMetadata(0);
                    Node n = meta.getAsTree("javax_imageio_1.0").getFirstChild();
                    while (n!=null) {
                        final String nodeName = n.getNodeName();
                        if (nodeName.equals("Dimension")) {
                            Node n2 = n.getFirstChild();
                            while (n2!=null) {
                                final String n2Name = n2.getNodeName();
                                if (n2Name.equals("HorizontalPixelSize")) {
                                    final NamedNodeMap nnm = n2.getAttributes();
                                    final Node n3 = nnm.item(0);
                                    xDPI = Math.round(25.4f / Float.parseFloat(n3.getNodeValue()));
                                }
                                else if (n2.equals("VerticalPixelSize")) {
                                    final NamedNodeMap nnm = n2.getAttributes();
                                    final Node n3 = nnm.item(0);
                                    yDPI = Math.round(25.4f / Float.parseFloat(n3.getNodeValue()));
                                }
                                n2 = n2.getNextSibling();
                            }
                        }
                        n = n.getNextSibling();
                    }
                    final double dpi = (xDPI!=null&&yDPI!=null&&xDPI == yDPI) ? xDPI.doubleValue() : 96.0;

                    originalWidth = Double.valueOf(reader.getWidth(0) * 2540d / dpi);
                    originalHeight = Double.valueOf(reader.getHeight(0) * 2540d / dpi);
                }
                imageInput.close();
            }
        }
        catch(Exception e) {
            //
        };
        return originalWidth!=null&&originalHeight!=null ? Pair.of(originalWidth, originalHeight) : null;
    }

    public static int junitTestParam = 0;
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.filter.core/src/com/openexchange/office/filter/core/Tools.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.core;

import java.awt.image.BufferedImage;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Iterator;
import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.metadata.IIOMetadata;
import javax.imageio.stream.ImageInputStream;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.tuple.Pair;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import com.openexchange.imagetransformation.ImageInformation;
import com.openexchange.java.BoolReference;
import com.openexchange.tools.images.ImageTransformationUtility;

public class Tools {

    public static double[] rotatePoint(double ptX, double ptY, double refX, double refY, double rotation) {
        ptX -= refX;
        ptY -= refY;
        double x = ptX;
        double y = ptY;
        double a = (Math.PI * rotation) / 180.0;
        double s = Math.sin(a);
        double c = Math.cos(a);
        ptX = x * c - y * s;
        ptY = x * s + y * c;
        ptX += refX;
        ptY += refY;
        double[] pts = new double[2];
        pts[0] = ptX;
        pts[1] = ptY;
        return pts;
    }

    public static Pair<Integer, Integer> getPixelSizeFromImage(InputStream inputStream) {

        Pair<Integer, Integer> pixelSize = null;
        BufferedInputStream bufferedInputStream = null;

        try {
            if(inputStream!=null) {
                bufferedInputStream = new BufferedInputStream(inputStream);
                final ImageInformation imageInformation = ImageTransformationUtility.readImageInformation(bufferedInputStream, new BoolReference(false));
                if(imageInformation!=null) {
                    pixelSize = Pair.of(Integer.valueOf(imageInformation.width), Integer.valueOf(imageInformation.height));
                }
                else {
                    bufferedInputStream.reset();
                    final BufferedImage image = ImageIO.read(bufferedInputStream);
                    if(image!=null) {
                        pixelSize = Pair.of(Integer.valueOf(image.getWidth()), Integer.valueOf(image.getHeight()));
                    }
                }
            }
        }
        catch(IOException e) {
            //
        }
        IOUtils.closeQuietly(bufferedInputStream);
        IOUtils.closeQuietly(inputStream);
        return pixelSize;
    }

    public static Pair<Double, Double> getDPIFromImage(InputStream is) {

        Double xDPI = null;
        Double yDPI = null;

        try {

            final ImageInputStream imageInput = ImageIO.createImageInputStream(is);
            if(imageInput!=null) {
                final Iterator<ImageReader> it = ImageIO.getImageReaders(imageInput);
                if (it.hasNext()) {


                    final ImageReader reader = it.next();
                    reader.setInput(imageInput);
                    final IIOMetadata meta = reader.getImageMetadata(0);
                    Node n = meta.getAsTree("javax_imageio_1.0").getFirstChild();
                    while (n!=null) {
                        final String nodeName = n.getNodeName();
                        if (nodeName.equals("Dimension")) {
                            Node n2 = n.getFirstChild();
                            while (n2!=null) {
                                final String n2Name = n2.getNodeName();
                                if (n2Name.equals("HorizontalPixelSize")) {
                                    final NamedNodeMap nnm = n2.getAttributes();
                                    final Node n3 = nnm.item(0);
                                    xDPI = 25.4d / Double.parseDouble(n3.getNodeValue());
                                }
                                else if (n2.equals("VerticalPixelSize")) {
                                    final NamedNodeMap nnm = n2.getAttributes();
                                    final Node n3 = nnm.item(0);
                                    yDPI = 25.4d / Double.parseDouble(n3.getNodeValue());
                                }
                                n2 = n2.getNextSibling();
                            }
                        }
                        n = n.getNextSibling();
                    }
                }
                imageInput.close();
            }
        }
        catch(Exception e) {
            //
        };
        return xDPI == null ? null : Pair.of(xDPI, yDPI==null ? xDPI : yDPI);

    }

    /*
     * If available this method returns the original size of the given graphic in 1/100thmm
     */

    public static Pair<Double, Double> getOriginalSizeFromImage(InputStream is) {

        Double originalWidth = null;
        Double originalHeight = null;

        try {

            final ImageInputStream imageInput = ImageIO.createImageInputStream(is);
            if(imageInput!=null) {
                final Iterator<ImageReader> it = ImageIO.getImageReaders(imageInput);
                if (it.hasNext()) {

                    Integer xDPI = null;
                    Integer yDPI = null;

                    final ImageReader reader = it.next();
                    reader.setInput(imageInput);
                    final IIOMetadata meta = reader.getImageMetadata(0);
                    Node n = meta.getAsTree("javax_imageio_1.0").getFirstChild();
                    while (n!=null) {
                        final String nodeName = n.getNodeName();
                        if (nodeName.equals("Dimension")) {
                            Node n2 = n.getFirstChild();
                            while (n2!=null) {
                                final String n2Name = n2.getNodeName();
                                if (n2Name.equals("HorizontalPixelSize")) {
                                    final NamedNodeMap nnm = n2.getAttributes();
                                    final Node n3 = nnm.item(0);
                                    xDPI = Math.round(25.4f / Float.parseFloat(n3.getNodeValue()));
                                }
                                else if (n2.equals("VerticalPixelSize")) {
                                    final NamedNodeMap nnm = n2.getAttributes();
                                    final Node n3 = nnm.item(0);
                                    yDPI = Math.round(25.4f / Float.parseFloat(n3.getNodeValue()));
                                }
                                n2 = n2.getNextSibling();
                            }
                        }
                        n = n.getNextSibling();
                    }
                    final double dpi = (xDPI!=null&&yDPI!=null&&xDPI == yDPI) ? xDPI.doubleValue() : 96.0;

                    originalWidth = Double.valueOf(reader.getWidth(0) * 2540d / dpi);
                    originalHeight = Double.valueOf(reader.getHeight(0) * 2540d / dpi);
                }
                imageInput.close();
            }
        }
        catch(Exception e) {
            //
        };
        return originalWidth!=null&&originalHeight!=null ? Pair.of(originalWidth, originalHeight) : null;
    }

    public static int junitTestParam = 0;
}
